@@ -736,7 +736,7 @@ class AutoCrosswalk(object):
         # ---------------------------------------------------------------------
         # Estimate transition proabability matrix
         # ---------------------------------------------------------------------
-        transition_matrix = self.estimate_transition_matrix(df_from=df_from,
+        self.transition_matrix = self.estimate_transition_matrix(df_from=df_from,
                                                             df_to=df_to,
                                                             use_existing_transition_matrix=use_existing_transition_matrix,
                                                             numeric_key=numeric_key,
@@ -757,7 +757,7 @@ class AutoCrosswalk(object):
                 
         if self.prioritize_exact_match:
             # Find exact matches
-            crosswalk_exact = self._find_exact_match(transition_matrix=transition_matrix,
+            crosswalk_exact = self._find_exact_match(transition_matrix=self.transition_matrix,
                                                      which_priority=which_priority)
             
             # Update existing crosswalk
@@ -768,11 +768,11 @@ class AutoCrosswalk(object):
         ## Find nbest matches
         # Mask those not found by now
         mask_find = crosswalk.isna().any(axis=1)
-        mask_lookup = transition_matrix["average"].index.isin(crosswalk.loc[mask_find].index)
+        mask_lookup = self.transition_matrix["average"].index.isin(crosswalk.loc[mask_find].index)
 
         if mask_lookup.sum()>0:
             # Find nbest candidates
-            crosswalk_nbest = self._find_nbest_match(transition_matrix=transition_matrix["average"].loc[mask_lookup],
+            crosswalk_nbest = self._find_nbest_match(transition_matrix=self.transition_matrix["average"].loc[mask_lookup],
                                                      n=self.n_best_match)
     
             crosswalks.append(crosswalk_nbest)
@@ -780,7 +780,7 @@ class AutoCrosswalk(object):
         if self.enforce_completeness:
             
             # Transpose all transition matrices
-            transition_matrix_to = self._transpose_transition_matrix(transition_matrix=transition_matrix)
+            transition_matrix_to = self._transpose_transition_matrix(transition_matrix=self.transition_matrix)
             
             # Make sure that all keys in "df_to" are also matched
             crosswalk_to = self._prepare_crosswalk(df=df_to,
@@ -842,7 +842,7 @@ class AutoCrosswalk(object):
         Perform crosswalk
         """
         self._check_prefix(prefix=prefix, df=df)
-        
+
         # Sanity check
         values = self.__fix_values(v=values)
         self._check_cols(df=df, cols=values)
@@ -906,15 +906,15 @@ class AutoCrosswalk(object):
             df_from = df.loc[~mask_na]
 
             # Generate crosswalk
-            crosswalk = self.generate_crosswalk(df_from=df_from,
-                                                df_to=df,
-                                                numeric_key=numeric_key,
-                                                text_key=text_key,
-                                                context_key=context_key,
-                                                weights=weights)
+            self.crosswalk = self.generate_crosswalk(df_from=df_from,
+                                                   df_to=df,
+                                                    numeric_key=numeric_key,
+                                                    text_key=text_key,
+                                                    context_key=context_key,
+                                                    weights=weights)
             
             # Perform crosswalk
-            df_updated = self.perform_crosswalk(crosswalk=crosswalk,
+            df_updated = self.perform_crosswalk(crosswalk=self.crosswalk,
                                                 df=df_from,
                                                 values=values,
                                                 by=by)
